aboutsummaryrefslogtreecommitdiff
path: root/next-gen-gui
diff options
context:
space:
mode:
authorDimitri Papadopoulos Orfanos <3234522+DimitriPapadopoulos@users.noreply.github.com>2023-03-21 08:07:28 +0100
committerGitHub <noreply@github.com>2023-03-21 08:07:28 +0100
commit526e21ae261ed5b05d2b0fcb4907f6dd12e47f90 (patch)
treee21ea1c3fc376552ca06b94ff264d45fc2efe640 /next-gen-gui
parentbc371eacf6ec9e76079e128d1bca594aa7b44be8 (diff)
downloadsyncthing-526e21ae261ed5b05d2b0fcb4907f6dd12e47f90.tar.gz
syncthing-526e21ae261ed5b05d2b0fcb4907f6dd12e47f90.zip
all: Fix typos found by codespell (#8833)
Diffstat (limited to 'next-gen-gui')
-rw-r--r--next-gen-gui/src/app/http-interceptors/caching.interceptor.ts12
-rw-r--r--next-gen-gui/src/app/services/db-completion.service.ts4
-rw-r--r--next-gen-gui/src/app/services/db-status.service.ts4
3 files changed, 10 insertions, 10 deletions
diff --git a/next-gen-gui/src/app/services/db-completion.service.ts b/next-gen-gui/src/app/services/db-completion.service.ts
index d7d5ce668..e3dffa7c6 100644
--- a/next-gen-gui/src/app/services/db-completion.service.ts
+++ b/next-gen-gui/src/app/services/db-completion.service.ts
@@ -36,7 +36,7 @@ export class DbCompletionService {
.get<Completion>(this.dbStatusUrl, httpOptions)
.pipe(
map(res => {
- // Remove from array in developement
+ // Remove from array in development
// in-memory-web-api returns arrays
if (!environment.production) {
const a: any = res as any;
@@ -48,4 +48,4 @@ export class DbCompletionService {
})
);
}
-} \ No newline at end of file
+}
diff --git a/next-gen-gui/src/app/services/db-status.service.ts b/next-gen-gui/src/app/services/db-status.service.ts
index 6c51581c7..7c0bfe8d4 100644
--- a/next-gen-gui/src/app/services/db-status.service.ts
+++ b/next-gen-gui/src/app/services/db-status.service.ts
@@ -28,7 +28,7 @@ export class DbStatusService {
.get<Folder.Status>(this.dbStatusUrl, httpOptions)
.pipe(
map(res => {
- // Remove from array in developement
+ // Remove from array in development
// in-memory-web-api returns arrays
if (!environment.production) {
const a: any = res as any;
@@ -40,4 +40,4 @@ export class DbStatusService {
})
);
}
-} \ No newline at end of file
+}
diff --git a/next-gen-gui/src/app/http-interceptors/caching.interceptor.ts b/next-gen-gui/src/app/http-interceptors/caching.interceptor.ts
index 48112b521..7139c945d 100644
--- a/next-gen-gui/src/app/http-interceptors/caching.interceptor.ts
+++ b/next-gen-gui/src/app/http-interceptors/caching.interceptor.ts
@@ -16,8 +16,8 @@ export class CachingInterceptor implements HttpInterceptor {
constructor(private cache: RequestCacheService) { }
intercept(req: HttpRequest<any>, next: HttpHandler) {
- // continue if not cachable.
- if (!isCachable(req)) { return next.handle(req); }
+ // continue if not cacheable.
+ if (!isCacheable(req)) { return next.handle(req); }
const cachedResponse = this.cache.get(req);
return cachedResponse ?
@@ -25,9 +25,9 @@ export class CachingInterceptor implements HttpInterceptor {
}
}
-/** Is this request cachable? */
-function isCachable(req: HttpRequest<any>) {
- // Only GET requests are cachable
+/** Is this request cacheable? */
+function isCacheable(req: HttpRequest<any>) {
+ // Only GET requests are cacheable
return req.method === 'GET';
/*
return req.method === 'GET' &&
@@ -55,4 +55,4 @@ function sendRequest(
}
})
);
-} \ No newline at end of file
+}